========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |appveyor| |requires|
        | |codecov|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|
.. |docs| image:: https://readthedocs.org/projects/py_dss_interface/badge/?style=flat
    :target: https://readthedocs.org/projects/py_dss_interface
    :alt: Documentation Status

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/PauloRadatz/py_dss_interface?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/PauloRadatz/py_dss_interface

.. |codecov| image:: https://codecov.io/gh/PauloRadatz/py_dss_interface/branch/master/graphs/badge.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/PauloRadatz/py_dss_interface

.. |version| image:: https://img.shields.io/pypi/v/py-dss-interface.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/py-dss-interface

.. |wheel| image:: https://img.shields.io/pypi/wheel/py-dss-interface.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/py-dss-interface

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/py-dss-interface.svg
    :alt: Supported versions
    :target: https://pypi.org/project/py-dss-interface

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/py-dss-interface.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/py-dss-interface

.. |commits-since| image:: https://img.shields.io/github/commits-since/PauloRadatz/py_dss_interface/v0.0.0.svg
    :alt: Commits since latest release
    :target: https://github.com/PauloRadatz/py_dss_interface/compare/v0.0.0...master



.. end-badges

py-dss-interface is a Windows Python package providing access to OpenDSS direct dll version of OpenDSS - Version 9.2.0.1 (64-bit build); License Status: Open and Version 9.2.0.1 (32-bit build); License Status: Open.

* Free software: MIT license

Disclaimer
============
This Python Package is purely responsibility of Paulo Radatz and not his employer. Use this package at your own risk.

Installation
============

::

    pip install py-dss-interface

Documentation
=============
You can access the documentation through:

1 - The Read the Docs.

https://py_dss_interface.readthedocs.io/

2 - Another good resource is the OpenDSS_Direct_DLL.pdf doc created by Davis Montenegro. The package has been done based on this documentation.

https://sourceforge.net/p/electricdss/code/HEAD/tree/trunk/Version8/Distrib/Doc/OpenDSS_Direct_DLL.pdf


Thanks
=============
I want to thank Ênio Viana and Rodolfo Pilar Londero for all their contribution to the new version of the tool.


